@@ -13,10 +13,13 @@ from function_scheduling_distributed_framework.consumers.persist_queue_consumer
 from function_scheduling_distributed_framework.consumers.rabbitmq_amqpstorm_consumer import RabbitmqConsumerAmqpStorm
 from function_scheduling_distributed_framework.consumers.rabbitmq_pika_consumer import RabbitmqConsumer
 from function_scheduling_distributed_framework.consumers.rabbitmq_rabbitpy_consumer import RabbitmqConsumerRabbitpy
+from function_scheduling_distributed_framework.consumers.redis_brpoplpush_consumer import RedisBrpopLpushConsumer
 from function_scheduling_distributed_framework.consumers.redis_consumer import RedisConsumer
 from function_scheduling_distributed_framework.consumers.redis_consumer_ack_able import RedisConsumerAckAble
 from function_scheduling_distributed_framework.consumers.rocketmq_consumer import RocketmqConsumer
 from function_scheduling_distributed_framework.consumers.sqlachemy_consumer import SqlachemyConsumer
+from function_scheduling_distributed_framework.consumers.redis_stream_consumer import RedisStreamConsumer
+from function_scheduling_distributed_framework.consumers.zeromq_consumer import ZeroMqConsumer
 
 
 def get_consumer(*args, broker_kind=0, **kwargs):
@@ -27,11 +30,11 @@ def get_consumer(*args, broker_kind=0, **kwargs):
     :return:
     """
     broker_kind__consumer_type_map = {
-        0: RabbitmqConsumer,
+        4: RabbitmqConsumer,
         1: RabbitmqConsumerRabbitpy,
         2: RedisConsumer,
         3: LocalPythonQueueConsumer,
-        4: RabbitmqConsumerAmqpStorm,
+        0: RabbitmqConsumerAmqpStorm,
         5: MongoMqConsumer,
         6: PersistQueueConsumer,
         7: NsqConsumer,
@@ -39,6 +42,9 @@ def get_consumer(*args, broker_kind=0, **kwargs):
         9: RedisConsumerAckAble,
         10: SqlachemyConsumer,
         11: RocketmqConsumer,
+        12: RedisStreamConsumer,
+        13: ZeroMqConsumer,
+        14: RedisBrpopLpushConsumer
     }
     if broker_kind not in broker_kind__consumer_type_map:
         raise ValueError(f'设置的中间件种类数字不正确,你设置的值是 {broker_kind} ')
