@@ -4,6 +4,7 @@
 import copy
 from typing import Callable
 
+from function_scheduling_distributed_framework.publishers.zeromq_publisher import ZeroMqPublisher
 from function_scheduling_distributed_framework.publishers.kafka_publisher import KafkaPublisher
 from function_scheduling_distributed_framework.publishers.local_python_queue_publisher import LocalPythonQueuePublisher
 from function_scheduling_distributed_framework.publishers.mongomq_publisher import MongoMqPublisher
@@ -15,7 +16,7 @@ from function_scheduling_distributed_framework.publishers.rabbitmq_rabbitpy_publ
 from function_scheduling_distributed_framework.publishers.redis_publisher import RedisPublisher
 from function_scheduling_distributed_framework.publishers.rocketmq_publisher import RocketmqPublisher
 from function_scheduling_distributed_framework.publishers.sqla_queue_publisher import SqlachemyQueuePublisher
-
+from function_scheduling_distributed_framework.publishers.redis_stream_publisher import RedisStreamPublisher
 
 def get_publisher(queue_name, *, log_level_int=10, logger_prefix='', is_add_file_handler=True,
                   clear_queue_within_init=False, is_add_publish_time=True, consuming_function: Callable = None,
@@ -35,11 +36,11 @@ def get_publisher(queue_name, *, log_level_int=10, logger_prefix='', is_add_file
     all_kwargs = copy.deepcopy(locals())
     all_kwargs.pop('broker_kind')
     broker_kind__publisher_type_map = {
-        0: RabbitmqPublisher,
+        4: RabbitmqPublisher,
         1: RabbitmqPublisherUsingRabbitpy,
         2: RedisPublisher,
         3: LocalPythonQueuePublisher,
-        4: RabbitmqPublisherUsingAmqpStorm,
+        0: RabbitmqPublisherUsingAmqpStorm,
         5: MongoMqPublisher,
         6: PersistQueuePublisher,
         7: NsqPublisher,
@@ -47,6 +48,9 @@ def get_publisher(queue_name, *, log_level_int=10, logger_prefix='', is_add_file
         9: RedisPublisher,
         10: SqlachemyQueuePublisher,
         11:RocketmqPublisher,
+        12:RedisStreamPublisher,
+        13:ZeroMqPublisher,
+        14:RedisPublisher
     }
     if broker_kind not in broker_kind__publisher_type_map:
         raise ValueError(f'设置的中间件种类数字不正确,你设置的值是 {broker_kind} ')
