@@ -3,8 +3,7 @@
 # @Time    : 2019/8/8 0008 9:51
 
 
-# 你需要使用patch_frame_config函数打猴子补丁的方式修改这里的配置就可以了，很简单。最好不要去改框架源码这里，但也可以改这里。
-# 还可以在你项目根目录下自动生成的 distributed_frame_config.py 文件种修改配置，会被自动读取到。
+# 你项目根目录下自动生成的 distributed_frame_config.py 文件种修改配置，会被自动读取到。
 
 MONGO_CONNECT_URL = f'mongodb://myUserAdmin:8mwTdy1klnSYepNo@{"192.168.199.202"}:27016/admin'
 
@@ -33,6 +32,6 @@ ROCKETMQ_NAMESRV_ADDR = '192.168.199.202:9876'
 
 # nb_log包的第几个日志模板，内置了7个模板，可以在你当前项目根目录下的nb_log_config.py文件扩展模板。
 NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7  # 7是简短的不可跳转，5是可点击跳转的
-FSDF_DEVELOP_LOG_LEVEL = 50   # 开发时候的日志，进攻自己用，所以日志级别跳到最高
+FSDF_DEVELOP_LOG_LEVEL = 50   # 开发时候的日志，仅供自己用，所以日志级别跳到最高
 
 TIMEZONE = 'Asia/Shanghai'
